summaryrefslogtreecommitdiffstats
path: root/karm/task.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'karm/task.cpp')
-rw-r--r--karm/task.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/karm/task.cpp b/karm/task.cpp
index b150a94d..cf37ee43 100644
--- a/karm/task.cpp
+++ b/karm/task.cpp
@@ -22,21 +22,21 @@ const int gSecondsPerMinute = 60;
TQPtrVector<TQPixmap> *Task::icons = 0;
Task::Task( const TQString& taskName, long minutes, long sessionTime,
- DesktopList desktops, TaskView *parent)
- : TQObject(), TQListViewItem(parent)
+ DesktopList desktops, TaskView *tqparent)
+ : TQObject(), TQListViewItem(tqparent)
{
init(taskName, minutes, sessionTime, desktops, 0);
}
Task::Task( const TQString& taskName, long minutes, long sessionTime,
- DesktopList desktops, Task *parent)
- : TQObject(), TQListViewItem(parent)
+ DesktopList desktops, Task *tqparent)
+ : TQObject(), TQListViewItem(tqparent)
{
init(taskName, minutes, sessionTime, desktops, 0);
}
-Task::Task( KCal::Todo* todo, TaskView* parent )
- : TQObject(), TQListViewItem( parent )
+Task::Task( KCal::Todo* todo, TaskView* tqparent )
+ : TQObject(), TQListViewItem( tqparent )
{
long minutes = 0;
TQString name;
@@ -51,9 +51,9 @@ Task::Task( KCal::Todo* todo, TaskView* parent )
void Task::init( const TQString& taskName, long minutes, long sessionTime,
DesktopList desktops, int percent_complete)
{
// If our parent is the taskview then connect our totalTimesChanged
// signal to its receiver
- if ( ! parent() )
+ if ( ! tqparent() )
connect( this, TQT_SIGNAL( totalTimesChanged ( long, long ) ),
listView(), TQT_SLOT( taskTotalTimesChanged( long, long) ));
@@ -164,13 +164,13 @@ void Task::setPercentComplete(const int percent, KarmStorage *storage)
setPixmapProgress();
// When parent marked as complete, mark all children as complete as well.
// Complete tasks are not displayed in the task view, so if a parent is
// marked as complete and some of the children are not, then we get an error
// message. KArm actually keep chugging along in this case and displays the
// child tasks just fine, so an alternative solution is to remove that error
// message (from KarmStorage::load). But I think it makes more sense that
- // if you mark a parent task as complete, then all children should be
+ // if you mark a tqparent task as complete, then all tqchildren should be
// complete as well.
//
// This behavior is consistent with KOrganizer (as of 2003-09-24).
@@ -252,7 +252,7 @@ void Task::changeParentTotalTimes( long minutesSession, long minutes )
if ( isRoot() )
emit totalTimesChanged( minutesSession, minutes );
else
- parent()->changeTotalTimes( minutesSession, minutes );
+ tqparent()->changeTotalTimes( minutesSession, minutes );
}
bool Task::remove( TQPtrList<Task>& activeTasks, KarmStorage* storage)
@@ -290,7 +290,7 @@ TQString Task::fullName() const
if (isRoot())
return name();
else
- return parent()->fullName() + TQString::tqfromLatin1("/") + name();
+ return tqparent()->fullName() + TQString::tqfromLatin1("/") + name();
}
KCal::Todo* Task::asTodo(KCal::Todo* todo) const
@@ -390,10 +390,10 @@ void Task::cut()
{
//kdDebug(5970) << "Task::cut - " << name() << endl;
changeParentTotalTimes( -_totalSessionTime, -_totalTime);
- if ( ! parent())
+ if ( ! tqparent())
listView()->takeItem(this);
else
- parent()->takeItem(this);
+ tqparent()->takeItem(this);
}
void Task::move(Task* destination)
@@ -51,9 +51,9 @@ Task::Task( KCal::Todo* todo, TaskView* parent )
DesktopList desktops, int percent_complete)
{
- // If our parent is the taskview then connect our totalTimesChanged
+ // If our tqparent is the taskview then connect our totalTimesChanged
// signal to its receiver
@@ -164,13 +164,13 @@ void Task::setPercentComplete(const int percent, KarmStorage *storage)
setPixmapProgress();
- // When parent marked as complete, mark all children as complete as well.
- // Complete tasks are not displayed in the task view, so if a parent is
- // marked as complete and some of the children are not, then we get an error
+ // When tqparent marked as complete, mark all tqchildren as complete as well.
+ // Complete tasks are not displayed in the task view, so if a tqparent is
+ // marked as complete and some of the tqchildren are not, then we get an error
// message. KArm actually keep chugging along in this case and displays the
// child tasks just fine, so an alternative solution is to remove that error